# Antiderivatives
An antiderivative is useful when you know the rate of change, and you want to find a point from that rate of change

> A function $F$ is said to be an *antiderivative* of $f$ if $F'(x) = f(x)$ 
## Notation
The collection of all antiderivatives of a function $f$ is referred to as the *indefinite integral of $f$ with respect to $x$*, and is denoted by:
$$ \int f(x) dx $$
## Examples
> Find the antiderivative of the function $y = x^2$

1. We know that to find the derivative of the above function, you'd multiply by the exponent ($2$), and subtract 1 from the exponent.
2. To perform this operation in reverse:
	1. Add 1 to the exponent
	2. Multiply by $\dfrac{1}{n + 1}$
3. This gives us an antiderivative of $\dfrac{1}{3}x^3$ 
4. To check our work, work backwards.
5. The derivative of $\dfrac{1}{3}x^3$ is $\dfrac{1}{3} (3x^2)$
6. $= \dfrac{3}{3} x^2$


## Formulas

| Differentiation Formula                               | Integration Formula                                      |
| ----------------------------------------------------- | -------------------------------------------------------- |
| $\dfrac{d}{dx} x^n = nx^{x-1}$                        | $\int x^n dx = \dfrac{1}{n+1}x^{n+1}+ C$ for $n \ne -1$  |
| $\dfrac{d}{dx} kx = k$                                | $\int k \space dx = kx + C$                              |
| $\dfrac{d}{dx} \ln \|x\| = \dfrac{1}{x}$              | <br>$\int \dfrac{1}{x}dx = \ln \|x\| + C$                |
| $\dfrac{d}{dx} e^x = e^x$                             | <br>$\int e^x dx = e^x + C$                              |
| $\dfrac{d}{dx} a^x = (\ln{a}) a^x$                    | $\int a^xdx = \ln \|x\| + C$                             |
| $\dfrac{d}{dx} \sin x = \cos x$                       | $\int \cos(x) dx  = \sin (x) + C$                        |
| $\dfrac{d}{dx} \cos x = -\sin x$                      | $\int \sin(x)dx = \sin x + C$                            |
| $\dfrac{d}{dx} \tan{x} = \sec^2 x$                    | $\int \sec^2(x)dx = \tan(x) + C$                         |
| $\dfrac{d}{dx} \sec x = \sec x \tan x$                | $\int sec^2(x) dx = \sec(x) + C$                         |
| $\dfrac{d}{dx} \sin^{-1} x = \dfrac{1}{\sqrt{1-x^2}}$ | $\int \sec(x) \tan(x) dx = \sec x + C$                   |
| $\dfrac{d}{dx} \tan^{-1} x = \dfrac{1}{1+x^2}$        | $\int \dfrac{1}{\sqrt{1+x^2}}dx = \tan^{-1}x + C$        |
| $\dfrac{d}{dx} k f(x) = k f'(x)$                      | $\int k*f(x)dx = k\int f(x)dx$                           |
| $\dfrac{d}{dx} f(x) \pm g(x) = f'(x) \pm g'(x)$       | $\int (f(x) \pm g(x))dx = \int f(x) dx \pm \int g(x) dx$ |
